==> huaweicloudsdkdds-3.0.30rc0-py3-none-any.whl: huaweicloudsdkdds/v3/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import DdsClient
from huaweicloudsdkdds.v3.dds_client import DdsClient
from huaweicloudsdkdds.v3.dds_async_client import DdsAsyncClient
# import models into sdk package
from huaweicloudsdkdds.v3.model.add_sharding_node_request import AddShardingNodeRequest
from huaweicloudsdkdds.v3.model.add_sharding_node_response import AddShardingNodeResponse
from huaweicloudsdkdds.v3.model.add_sharding_node_volume_option import AddShardingNodeVolumeOption
from huaweicloudsdkdds.v3.model.attach_eip_request import AttachEipRequest
from huaweicloudsdkdds.v3.model.attach_eip_request_body import AttachEipRequestBody
from huaweicloudsdkdds.v3.model.attach_eip_response import AttachEipResponse
from huaweicloudsdkdds.v3.model.attach_internal_ip_request import AttachInternalIpRequest
from huaweicloudsdkdds.v3.model.attach_internal_ip_request_body import AttachInternalIpRequestBody
from huaweicloudsdkdds.v3.model.attach_internal_ip_response import AttachInternalIpResponse
from huaweicloudsdkdds.v3.model.backup_database import BackupDatabase
from huaweicloudsdkdds.v3.model.backup_for_list import BackupForList
from huaweicloudsdkdds.v3.model.backup_policy import BackupPolicy
from huaweicloudsdkdds.v3.model.backup_policy_item import BackupPolicyItem
from huaweicloudsdkdds.v3.model.backup_strategy import BackupStrategy
from huaweicloudsdkdds.v3.model.backup_strategy_for_item_response import BackupStrategyForItemResponse
from huaweicloudsdkdds.v3.model.batch_operate_instance_tag_request_body import BatchOperateInstanceTagRequestBody
from huaweicloudsdkdds.v3.model.batch_tag_action_request import BatchTagActionRequest
from huaweicloudsdkdds.v3.model.batch_tag_action_response import BatchTagActionResponse
from huaweicloudsdkdds.v3.model.cancel_eip_request import CancelEipRequest
from huaweicloudsdkdds.v3.model.cancel_eip_response import CancelEipResponse
from huaweicloudsdkdds.v3.model.create_database_role_request import CreateDatabaseRoleRequest
from huaweicloudsdkdds.v3.model.create_database_role_request_body import CreateDatabaseRoleRequestBody
from huaweicloudsdkdds.v3.model.create_database_role_response import CreateDatabaseRoleResponse
from huaweicloudsdkdds.v3.model.create_database_user_request import CreateDatabaseUserRequest
from huaweicloudsdkdds.v3.model.create_database_user_request_body import CreateDatabaseUserRequestBody
from huaweicloudsdkdds.v3.model.create_database_user_response import CreateDatabaseUserResponse
from huaweicloudsdkdds.v3.model.create_instance_flavor_option import CreateInstanceFlavorOption
from huaweicloudsdkdds.v3.model.create_instance_request import CreateInstanceRequest
from huaweicloudsdkdds.v3.model.create_instance_request_body import CreateInstanceRequestBody
from huaweicloudsdkdds.v3.model.create_instance_response import CreateInstanceResponse
from huaweicloudsdkdds.v3.model.create_manual_backup_option import CreateManualBackupOption
from huaweicloudsdkdds.v3.model.create_manual_backup_request import CreateManualBackupRequest
from huaweicloudsdkdds.v3.model.create_manual_backup_request_body import CreateManualBackupRequestBody
from huaweicloudsdkdds.v3.model.create_manual_backup_response import CreateManualBackupResponse
from huaweicloudsdkdds.v3.model.datastore import Datastore
from huaweicloudsdkdds.v3.model.datastore_item import DatastoreItem
from huaweicloudsdkdds.v3.model.delete_instance_request import DeleteInstanceRequest
from huaweicloudsdkdds.v3.model.delete_instance_response import DeleteInstanceResponse
from huaweicloudsdkdds.v3.model.delete_manual_backup_request import DeleteManualBackupRequest
from huaweicloudsdkdds.v3.model.delete_manual_backup_response import DeleteManualBackupResponse
from huaweicloudsdkdds.v3.model.download_slowlog_request import DownloadSlowlogRequest
from huaweicloudsdkdds.v3.model.download_slowlog_request_body import DownloadSlowlogRequestBody
from huaweicloudsdkdds.v3.model.download_slowlog_response import DownloadSlowlogResponse
from huaweicloudsdkdds.v3.model.download_slowlog_result import DownloadSlowlogResult
from huaweicloudsdkdds.v3.model.dss_pool_info import DssPoolInfo
from huaweicloudsdkdds.v3.model.enlarge_instance_request_body import EnlargeInstanceRequestBody
from huaweicloudsdkdds.v3.model.error_response import ErrorResponse
from huaweicloudsdkdds.v3.model.flavor import Flavor
from huaweicloudsdkdds.v3.model.get_backup_download_link_response_body_files import GetBackupDownloadLinkResponseBodyFiles
from huaweicloudsdkdds.v3.model.group_response_item import GroupResponseItem
from huaweicloudsdkdds.v3.model.instance_item import InstanceItem
from huaweicloudsdkdds.v3.model.instance_item_tag_item import InstanceItemTagItem
from huaweicloudsdkdds.v3.model.list_backups_request import ListBackupsRequest
from huaweicloudsdkdds.v3.model.list_backups_response import ListBackupsResponse
from huaweicloudsdkdds.v3.model.list_database_roles_request import ListDatabaseRolesRequest
from huaweicloudsdkdds.v3.model.list_database_roles_response import ListDatabaseRolesResponse
from huaweicloudsdkdds.v3.model.list_database_users_request import ListDatabaseUsersRequest
from huaweicloudsdkdds.v3.model.list_database_users_response import ListDatabaseUsersResponse
from huaweicloudsdkdds.v3.model.list_datastore_versions_request import ListDatastoreVersionsRequest
from huaweicloudsdkdds.v3.model.list_datastore_versions_response import ListDatastoreVersionsResponse
from huaweicloudsdkdds.v3.model.list_flavors_request import ListFlavorsRequest
from huaweicloudsdkdds.v3.model.list_flavors_response import ListFlavorsResponse
from huaweicloudsdkdds.v3.model.list_instance_tags_request import ListInstanceTagsRequest
from huaweicloudsdkdds.v3.model.list_instance_tags_response import ListInstanceTagsResponse
from huaweicloudsdkdds.v3.model.list_instances_by_tags_request import ListInstancesByTagsRequest
from huaweicloudsdkdds.v3.model.list_instances_by_tags_request_body import ListInstancesByTagsRequestBody
from huaweicloudsdkdds.v3.model.list_instances_by_tags_response import ListInstancesByTagsResponse
from huaweicloudsdkdds.v3.model.list_instances_request import ListInstancesRequest
from huaweicloudsdkdds.v3.model.list_instances_response import ListInstancesResponse
from huaweicloudsdkdds.v3.model.list_project_tags_request import ListProjectTagsRequest
from huaweicloudsdkdds.v3.model.list_project_tags_response import ListProjectTagsResponse
from huaweicloudsdkdds.v3.model.list_slow_logs_request import ListSlowLogsRequest
from huaweicloudsdkdds.v3.model.list_slow_logs_response import ListSlowLogsResponse
from huaweicloudsdkdds.v3.model.list_storage_type_request import ListStorageTypeRequest
from huaweicloudsdkdds.v3.model.list_storage_type_response import ListStorageTypeResponse
from huaweicloudsdkdds.v3.model.node_item import NodeItem
from huaweicloudsdkdds.v3.model.query_instance_response import QueryInstanceResponse
from huaweicloudsdkdds.v3.model.query_match_item import QueryMatchItem
from huaweicloudsdkdds.v3.model.query_project_tag_item import QueryProjectTagItem
from huaweicloudsdkdds.v3.model.query_resource_tag_item import QueryResourceTagItem
from huaweicloudsdkdds.v3.model.query_tag_item import QueryTagItem
from huaweicloudsdkdds.v3.model.reset_password_request import ResetPasswordRequest
from huaweicloudsdkdds.v3.model.reset_password_request_body import ResetPasswordRequestBody
from huaweicloudsdkdds.v3.model.reset_password_response import ResetPasswordResponse
from huaweicloudsdkdds.v3.model.resize_instance_option import ResizeInstanceOption
from huaweicloudsdkdds.v3.model.resize_instance_request import ResizeInstanceRequest
from huaweicloudsdkdds.v3.model.resize_instance_request_body import ResizeInstanceRequestBody
from huaweicloudsdkdds.v3.model.resize_instance_response import ResizeInstanceResponse
from huaweicloudsdkdds.v3.model.resize_instance_volume_option import ResizeInstanceVolumeOption
from huaweicloudsdkdds.v3.model.resize_instance_volume_request import ResizeInstanceVolumeRequest
from huaweicloudsdkdds.v3.model.resize_instance_volume_request_body import ResizeInstanceVolumeRequestBody
from huaweicloudsdkdds.v3.model.resize_instance_volume_response import ResizeInstanceVolumeResponse
from huaweicloudsdkdds.v3.model.restart_instance_request import RestartInstanceRequest
from huaweicloudsdkdds.v3.model.restart_instance_request_body import RestartInstanceRequestBody
from huaweicloudsdkdds.v3.model.restart_instance_response import RestartInstanceResponse
from huaweicloudsdkdds.v3.model.restore_point import RestorePoint
from huaweicloudsdkdds.v3.model.roles_option import RolesOption
from huaweicloudsdkdds.v3.model.set_backup_policy_request import SetBackupPolicyRequest
from huaweicloudsdkdds.v3.model.set_backup_policy_request_body import SetBackupPolicyRequestBody
from huaweicloudsdkdds.v3.model.set_backup_policy_response import SetBackupPolicyResponse
from huaweicloudsdkdds.v3.model.show_backup_download_link_request import ShowBackupDownloadLinkRequest
from huaweicloudsdkdds.v3.model.show_backup_download_link_response import ShowBackupDownloadLinkResponse
from huaweicloudsdkdds.v3.model.show_backup_policy_request import ShowBackupPolicyRequest
from huaweicloudsdkdds.v3.model.show_backup_policy_response import ShowBackupPolicyResponse
from huaweicloudsdkdds.v3.model.slowlog_result import SlowlogResult
from huaweicloudsdkdds.v3.model.storage import Storage
from huaweicloudsdkdds.v3.model.switch_ssl_request import SwitchSslRequest
from huaweicloudsdkdds.v3.model.switch_ssl_request_body import SwitchSslRequestBody
from huaweicloudsdkdds.v3.model.switch_ssl_response import SwitchSslResponse
from huaweicloudsdkdds.v3.model.switchover_replica_set_request import SwitchoverReplicaSetRequest
from huaweicloudsdkdds.v3.model.switchover_replica_set_response import SwitchoverReplicaSetResponse
from huaweicloudsdkdds.v3.model.tag_item import TagItem
from huaweicloudsdkdds.v3.model.update_instance_name_request import UpdateInstanceNameRequest
from huaweicloudsdkdds.v3.model.update_instance_name_response import UpdateInstanceNameResponse
from huaweicloudsdkdds.v3.model.update_instance_port_request import UpdateInstancePortRequest
from huaweicloudsdkdds.v3.model.update_instance_port_response import UpdateInstancePortResponse
from huaweicloudsdkdds.v3.model.update_name_request_body import UpdateNameRequestBody
from huaweicloudsdkdds.v3.model.update_port_request_body import UpdatePortRequestBody
from huaweicloudsdkdds.v3.model.update_security_group_request import UpdateSecurityGroupRequest
from huaweicloudsdkdds.v3.model.update_security_group_request_body import UpdateSecurityGroupRequestBody
from huaweicloudsdkdds.v3.model.update_security_group_response import UpdateSecurityGroupResponse
from huaweicloudsdkdds.v3.model.volume import Volume

==> huaweicloudsdkdds-3.0.32rc1-py3-none-any.whl: huaweicloudsdkdds/v3/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import DdsClient
from huaweicloudsdkdds.v3.dds_client import DdsClient
from huaweicloudsdkdds.v3.dds_async_client import DdsAsyncClient
# import models into sdk package
from huaweicloudsdkdds.v3.model.add_sharding_node_request import AddShardingNodeRequest
from huaweicloudsdkdds.v3.model.add_sharding_node_response import AddShardingNodeResponse
from huaweicloudsdkdds.v3.model.add_sharding_node_volume_option import AddShardingNodeVolumeOption
from huaweicloudsdkdds.v3.model.api_version import ApiVersion
from huaweicloudsdkdds.v3.model.attach_eip_request import AttachEipRequest
from huaweicloudsdkdds.v3.model.attach_eip_request_body import AttachEipRequestBody
from huaweicloudsdkdds.v3.model.attach_eip_response import AttachEipResponse
from huaweicloudsdkdds.v3.model.attach_internal_ip_request import AttachInternalIpRequest
from huaweicloudsdkdds.v3.model.attach_internal_ip_request_body import AttachInternalIpRequestBody
from huaweicloudsdkdds.v3.model.attach_internal_ip_response import AttachInternalIpResponse
from huaweicloudsdkdds.v3.model.backup_database import BackupDatabase
from huaweicloudsdkdds.v3.model.backup_for_list import BackupForList
from huaweicloudsdkdds.v3.model.backup_policy import BackupPolicy
from huaweicloudsdkdds.v3.model.backup_policy_item import BackupPolicyItem
from huaweicloudsdkdds.v3.model.backup_strategy import BackupStrategy
from huaweicloudsdkdds.v3.model.backup_strategy_for_item_response import BackupStrategyForItemResponse
from huaweicloudsdkdds.v3.model.batch_operate_instance_tag_request_body import BatchOperateInstanceTagRequestBody
from huaweicloudsdkdds.v3.model.batch_tag_action_request import BatchTagActionRequest
from huaweicloudsdkdds.v3.model.batch_tag_action_response import BatchTagActionResponse
from huaweicloudsdkdds.v3.model.cancel_eip_request import CancelEipRequest
from huaweicloudsdkdds.v3.model.cancel_eip_response import CancelEipResponse
from huaweicloudsdkdds.v3.model.check_password_request import CheckPasswordRequest
from huaweicloudsdkdds.v3.model.check_password_request_body import CheckPasswordRequestBody
from huaweicloudsdkdds.v3.model.check_password_response import CheckPasswordResponse
from huaweicloudsdkdds.v3.model.create_database_role_request import CreateDatabaseRoleRequest
from huaweicloudsdkdds.v3.model.create_database_role_request_body import CreateDatabaseRoleRequestBody
from huaweicloudsdkdds.v3.model.create_database_role_response import CreateDatabaseRoleResponse
from huaweicloudsdkdds.v3.model.create_database_user_request import CreateDatabaseUserRequest
from huaweicloudsdkdds.v3.model.create_database_user_request_body import CreateDatabaseUserRequestBody
from huaweicloudsdkdds.v3.model.create_database_user_response import CreateDatabaseUserResponse
from huaweicloudsdkdds.v3.model.create_instance_flavor_option import CreateInstanceFlavorOption
from huaweicloudsdkdds.v3.model.create_instance_request import CreateInstanceRequest
from huaweicloudsdkdds.v3.model.create_instance_request_body import CreateInstanceRequestBody
from huaweicloudsdkdds.v3.model.create_instance_response import CreateInstanceResponse
from huaweicloudsdkdds.v3.model.create_ip_request import CreateIpRequest
from huaweicloudsdkdds.v3.model.create_ip_request_body import CreateIpRequestBody
from huaweicloudsdkdds.v3.model.create_ip_response import CreateIpResponse
from huaweicloudsdkdds.v3.model.create_manual_backup_option import CreateManualBackupOption
from huaweicloudsdkdds.v3.model.create_manual_backup_request import CreateManualBackupRequest
from huaweicloudsdkdds.v3.model.create_manual_backup_request_body import CreateManualBackupRequestBody
from huaweicloudsdkdds.v3.model.create_manual_backup_response import CreateManualBackupResponse
from huaweicloudsdkdds.v3.model.datastore import Datastore
from huaweicloudsdkdds.v3.model.datastore_item import DatastoreItem
from huaweicloudsdkdds.v3.model.delete_instance_request import DeleteInstanceRequest
from huaweicloudsdkdds.v3.model.delete_instance_response import DeleteInstanceResponse
from huaweicloudsdkdds.v3.model.delete_manual_backup_request import DeleteManualBackupRequest
from huaweicloudsdkdds.v3.model.delete_manual_backup_response import DeleteManualBackupResponse
from huaweicloudsdkdds.v3.model.dss_pool_info import DssPoolInfo
from huaweicloudsdkdds.v3.model.enlarge_instance_request_body import EnlargeInstanceRequestBody
from huaweicloudsdkdds.v3.model.error_response import ErrorResponse
from huaweicloudsdkdds.v3.model.errorlog_result import ErrorlogResult
from huaweicloudsdkdds.v3.model.flavor import Flavor
from huaweicloudsdkdds.v3.model.get_backup_download_link_response_body_files import GetBackupDownloadLinkResponseBodyFiles
from huaweicloudsdkdds.v3.model.group_response_item import GroupResponseItem
from huaweicloudsdkdds.v3.model.instance_item import InstanceItem
from huaweicloudsdkdds.v3.model.instance_item_tag_item import InstanceItemTagItem
from huaweicloudsdkdds.v3.model.links import Links
from huaweicloudsdkdds.v3.model.list_api_version_request import ListApiVersionRequest
from huaweicloudsdkdds.v3.model.list_api_version_response import ListApiVersionResponse
from huaweicloudsdkdds.v3.model.list_auditlog_links_request import ListAuditlogLinksRequest
from huaweicloudsdkdds.v3.model.list_auditlog_links_response import ListAuditlogLinksResponse
from huaweicloudsdkdds.v3.model.list_auditlogs_request import ListAuditlogsRequest
from huaweicloudsdkdds.v3.model.list_auditlogs_response import ListAuditlogsResponse
from huaweicloudsdkdds.v3.model.list_auditlogs_result import ListAuditlogsResult
from huaweicloudsdkdds.v3.model.list_backups_request import ListBackupsRequest
from huaweicloudsdkdds.v3.model.list_backups_response import ListBackupsResponse
from huaweicloudsdkdds.v3.model.list_database_roles_request import ListDatabaseRolesRequest
from huaweicloudsdkdds.v3.model.list_database_roles_response import ListDatabaseRolesResponse
from huaweicloudsdkdds.v3.model.list_database_users_request import ListDatabaseUsersRequest
from huaweicloudsdkdds.v3.model.list_database_users_response import ListDatabaseUsersResponse
from huaweicloudsdkdds.v3.model.list_datastore_versions_request import ListDatastoreVersionsRequest
from huaweicloudsdkdds.v3.model.list_datastore_versions_response import ListDatastoreVersionsResponse
from huaweicloudsdkdds.v3.model.list_error_logs_request import ListErrorLogsRequest
from huaweicloudsdkdds.v3.model.list_error_logs_response import ListErrorLogsResponse
from huaweicloudsdkdds.v3.model.list_flavors_request import ListFlavorsRequest
from huaweicloudsdkdds.v3.model.list_flavors_response import ListFlavorsResponse
from huaweicloudsdkdds.v3.model.list_instance_tags_request import ListInstanceTagsRequest
from huaweicloudsdkdds.v3.model.list_instance_tags_response import ListInstanceTagsResponse
from huaweicloudsdkdds.v3.model.list_instances_by_tags_request import ListInstancesByTagsRequest
from huaweicloudsdkdds.v3.model.list_instances_by_tags_request_body import ListInstancesByTagsRequestBody
from huaweicloudsdkdds.v3.model.list_instances_by_tags_response import ListInstancesByTagsResponse
from huaweicloudsdkdds.v3.model.list_instances_request import ListInstancesRequest
from huaweicloudsdkdds.v3.model.list_instances_response import ListInstancesResponse
from huaweicloudsdkdds.v3.model.list_project_tags_request import ListProjectTagsRequest
from huaweicloudsdkdds.v3.model.list_project_tags_response import ListProjectTagsResponse
from huaweicloudsdkdds.v3.model.list_restore_collections_request import ListRestoreCollectionsRequest
from huaweicloudsdkdds.v3.model.list_restore_collections_response import ListRestoreCollectionsResponse
from huaweicloudsdkdds.v3.model.list_restore_databases_request import ListRestoreDatabasesRequest
from huaweicloudsdkdds.v3.model.list_restore_databases_response import ListRestoreDatabasesResponse
from huaweicloudsdkdds.v3.model.list_restore_times_request import ListRestoreTimesRequest
from huaweicloudsdkdds.v3.model.list_restore_times_response import ListRestoreTimesResponse
from huaweicloudsdkdds.v3.model.list_restore_times_response_body_restore_time import ListRestoreTimesResponseBodyRestoreTime
from huaweicloudsdkdds.v3.model.list_slow_logs_request import ListSlowLogsRequest
from huaweicloudsdkdds.v3.model.list_slow_logs_response import ListSlowLogsResponse
from huaweicloudsdkdds.v3.model.list_storage_type_request import ListStorageTypeRequest
from huaweicloudsdkdds.v3.model.list_storage_type_response import ListStorageTypeResponse
from huaweicloudsdkdds.v3.model.node_item import NodeItem
from huaweicloudsdkdds.v3.model.produce_auditlog_links_request_body import ProduceAuditlogLinksRequestBody
from huaweicloudsdkdds.v3.model.query_instance_response import QueryInstanceResponse
from huaweicloudsdkdds.v3.model.query_match_item import QueryMatchItem
from huaweicloudsdkdds.v3.model.query_project_tag_item import QueryProjectTagItem
from huaweicloudsdkdds.v3.model.query_resource_tag_item import QueryResourceTagItem
from huaweicloudsdkdds.v3.model.query_tag_item import QueryTagItem
from huaweicloudsdkdds.v3.model.reset_password_request import ResetPasswordRequest
from huaweicloudsdkdds.v3.model.reset_password_request_body import ResetPasswordRequestBody
from huaweicloudsdkdds.v3.model.reset_password_response import ResetPasswordResponse
from huaweicloudsdkdds.v3.model.resize_instance_option import ResizeInstanceOption
from huaweicloudsdkdds.v3.model.resize_instance_request import ResizeInstanceRequest
from huaweicloudsdkdds.v3.model.resize_instance_request_body import ResizeInstanceRequestBody
from huaweicloudsdkdds.v3.model.resize_instance_response import ResizeInstanceResponse
from huaweicloudsdkdds.v3.model.resize_instance_volume_option import ResizeInstanceVolumeOption
from huaweicloudsdkdds.v3.model.resize_instance_volume_request import ResizeInstanceVolumeRequest
from huaweicloudsdkdds.v3.model.resize_instance_volume_request_body import ResizeInstanceVolumeRequestBody
from huaweicloudsdkdds.v3.model.resize_instance_volume_response import ResizeInstanceVolumeResponse
from huaweicloudsdkdds.v3.model.restart_instance_request import RestartInstanceRequest
from huaweicloudsdkdds.v3.model.restart_instance_request_body import RestartInstanceRequestBody
from huaweicloudsdkdds.v3.model.restart_instance_response import RestartInstanceResponse
from huaweicloudsdkdds.v3.model.restore_instance_from_collection_request import RestoreInstanceFromCollectionRequest
from huaweicloudsdkdds.v3.model.restore_instance_from_collection_request_body import RestoreInstanceFromCollectionRequestBody
from huaweicloudsdkdds.v3.model.restore_instance_from_collection_request_body_collections import RestoreInstanceFromCollectionRequestBodyCollections
from huaweicloudsdkdds.v3.model.restore_instance_from_collection_request_body_restore_collections import RestoreInstanceFromCollectionRequestBodyRestoreCollections
from huaweicloudsdkdds.v3.model.restore_instance_from_collection_response import RestoreInstanceFromCollectionResponse
from huaweicloudsdkdds.v3.model.restore_instance_request import RestoreInstanceRequest
from huaweicloudsdkdds.v3.model.restore_instance_request_body import RestoreInstanceRequestBody
from huaweicloudsdkdds.v3.model.restore_instance_response import RestoreInstanceResponse
from huaweicloudsdkdds.v3.model.restore_point import RestorePoint
from huaweicloudsdkdds.v3.model.roles_option import RolesOption
from huaweicloudsdkdds.v3.model.set_auditlog_policy_request import SetAuditlogPolicyRequest
from huaweicloudsdkdds.v3.model.set_auditlog_policy_request_body import SetAuditlogPolicyRequestBody
from huaweicloudsdkdds.v3.model.set_auditlog_policy_response import SetAuditlogPolicyResponse
from huaweicloudsdkdds.v3.model.set_backup_policy_request import SetBackupPolicyRequest
from huaweicloudsdkdds.v3.model.set_backup_policy_request_body import SetBackupPolicyRequestBody
from huaweicloudsdkdds.v3.model.set_backup_policy_response import SetBackupPolicyResponse
from huaweicloudsdkdds.v3.model.show_api_version_request import ShowApiVersionRequest
from huaweicloudsdkdds.v3.model.show_api_version_response import ShowApiVersionResponse
from huaweicloudsdkdds.v3.model.show_auditlog_policy_request import ShowAuditlogPolicyRequest
from huaweicloudsdkdds.v3.model.show_auditlog_policy_response import ShowAuditlogPolicyResponse
from huaweicloudsdkdds.v3.model.show_backup_download_link_request import ShowBackupDownloadLinkRequest
from huaweicloudsdkdds.v3.model.show_backup_download_link_response import ShowBackupDownloadLinkResponse
from huaweicloudsdkdds.v3.model.show_backup_policy_request import ShowBackupPolicyRequest
from huaweicloudsdkdds.v3.model.show_backup_policy_response import ShowBackupPolicyResponse
from huaweicloudsdkdds.v3.model.slowlog_result import SlowlogResult
from huaweicloudsdkdds.v3.model.source import Source
from huaweicloudsdkdds.v3.model.storage import Storage
from huaweicloudsdkdds.v3.model.switch_ssl_request import SwitchSslRequest
from huaweicloudsdkdds.v3.model.switch_ssl_request_body import SwitchSslRequestBody
from huaweicloudsdkdds.v3.model.switch_ssl_response import SwitchSslResponse
from huaweicloudsdkdds.v3.model.switchover_replica_set_request import SwitchoverReplicaSetRequest
from huaweicloudsdkdds.v3.model.switchover_replica_set_response import SwitchoverReplicaSetResponse
from huaweicloudsdkdds.v3.model.tag_item import TagItem
from huaweicloudsdkdds.v3.model.target import Target
from huaweicloudsdkdds.v3.model.update_instance_name_request import UpdateInstanceNameRequest
from huaweicloudsdkdds.v3.model.update_instance_name_response import UpdateInstanceNameResponse
from huaweicloudsdkdds.v3.model.update_instance_port_request import UpdateInstancePortRequest
from huaweicloudsdkdds.v3.model.update_instance_port_response import UpdateInstancePortResponse
from huaweicloudsdkdds.v3.model.update_name_request_body import UpdateNameRequestBody
from huaweicloudsdkdds.v3.model.update_port_request_body import UpdatePortRequestBody
from huaweicloudsdkdds.v3.model.update_security_group_request import UpdateSecurityGroupRequest
from huaweicloudsdkdds.v3.model.update_security_group_request_body import UpdateSecurityGroupRequestBody
from huaweicloudsdkdds.v3.model.update_security_group_response import UpdateSecurityGroupResponse
from huaweicloudsdkdds.v3.model.volume import Volume
